@@ -6,12 +6,13 @@
 
 from PyQt5 import QtCore, QtGui, QtWidgets
 
+
 class Ui_Decoder(object):
     def setupUi(self, Decoder):
         Decoder.setObjectName("Decoder")
         Decoder.setWindowModality(QtCore.Qt.WindowModal)
         Decoder.resize(1018, 590)
-        Decoder.setModal(True)
+        Decoder.setModal(False)
         self.verticalLayout_4 = QtWidgets.QVBoxLayout(Decoder)
         self.verticalLayout_4.setObjectName("verticalLayout_4")
         self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
@@ -38,7 +39,7 @@ class Ui_Decoder(object):
         self.label_8.setObjectName("label_8")
         self.verticalLayout_2.addWidget(self.label_8)
         self.basefunctions = QtWidgets.QListWidget(Decoder)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.basefunctions.sizePolicy().hasHeightForWidth())
@@ -51,7 +52,7 @@ class Ui_Decoder(object):
         self.label_9.setObjectName("label_9")
         self.verticalLayout_2.addWidget(self.label_9)
         self.additionalfunctions = QtWidgets.QListWidget(Decoder)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.additionalfunctions.sizePolicy().hasHeightForWidth())
@@ -61,8 +62,6 @@ class Ui_Decoder(object):
         self.additionalfunctions.setObjectName("additionalfunctions")
         self.verticalLayout_2.addWidget(self.additionalfunctions)
         self.horizontalLayout.addLayout(self.verticalLayout_2)
-        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
-        self.horizontalLayout.addItem(spacerItem1)
         self.verticalLayout = QtWidgets.QVBoxLayout()
         self.verticalLayout.setObjectName("verticalLayout")
         self.label = QtWidgets.QLabel(Decoder)
@@ -75,7 +74,7 @@ class Ui_Decoder(object):
         self.label.setObjectName("label")
         self.verticalLayout.addWidget(self.label)
         self.decoderchain = ListWidget(Decoder)
-        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
+        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.decoderchain.sizePolicy().hasHeightForWidth())
@@ -90,8 +89,6 @@ class Ui_Decoder(object):
         self.decoderchain.setObjectName("decoderchain")
         self.verticalLayout.addWidget(self.decoderchain)
         self.horizontalLayout.addLayout(self.verticalLayout)
-        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
-        self.horizontalLayout.addItem(spacerItem2)
         self.verticalLayout_3 = QtWidgets.QVBoxLayout()
         self.verticalLayout_3.setObjectName("verticalLayout_3")
         self.gb_infoandoptions = QtWidgets.QGroupBox(Decoder)
@@ -195,8 +192,8 @@ class Ui_Decoder(object):
         self.btnChooseEncoder.setObjectName("btnChooseEncoder")
         self.horizontalLayout_4.addWidget(self.btnChooseEncoder)
         self.verticalLayout_6.addLayout(self.horizontalLayout_4)
-        spacerItem3 = QtWidgets.QSpacerItem(20, 158, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
-        self.verticalLayout_6.addItem(spacerItem3)
+        spacerItem1 = QtWidgets.QSpacerItem(20, 158, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
+        self.verticalLayout_6.addItem(spacerItem1)
         self.optionWidget.addWidget(self.page_external)
         self.page_data_whitening = QtWidgets.QWidget()
         self.page_data_whitening.setObjectName("page_data_whitening")
@@ -272,44 +269,48 @@ class Ui_Decoder(object):
         self.morse_wait.setObjectName("morse_wait")
         self.optionWidget.addWidget(self.page_morse)
         self.verticalLayout_5.addWidget(self.optionWidget)
+        self.btnAddtoYourDecoding = QtWidgets.QPushButton(self.gb_infoandoptions)
+        self.btnAddtoYourDecoding.setObjectName("btnAddtoYourDecoding")
+        self.verticalLayout_5.addWidget(self.btnAddtoYourDecoding)
         self.optionWidget.raise_()
         self.info.raise_()
+        self.btnAddtoYourDecoding.raise_()
         self.verticalLayout_3.addWidget(self.gb_infoandoptions)
         self.horizontalLayout.addLayout(self.verticalLayout_3)
         self.verticalLayout_4.addLayout(self.horizontalLayout)
         self.gridLayout_2 = QtWidgets.QGridLayout()
         self.gridLayout_2.setObjectName("gridLayout_2")
-        self.label_3 = QtWidgets.QLabel(Decoder)
-        self.label_3.setObjectName("label_3")
-        self.gridLayout_2.addWidget(self.label_3, 4, 0, 1, 1)
-        self.combobox_signals = QtWidgets.QComboBox(Decoder)
-        self.combobox_signals.setObjectName("combobox_signals")
-        self.combobox_signals.addItem("")
-        self.gridLayout_2.addWidget(self.combobox_signals, 1, 0, 1, 1)
-        self.output = QtWidgets.QLineEdit(Decoder)
-        self.output.setReadOnly(True)
-        self.output.setObjectName("output")
-        self.gridLayout_2.addWidget(self.output, 5, 0, 1, 2)
-        self.decoding_errors_label = QtWidgets.QLabel(Decoder)
-        self.decoding_errors_label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
-        self.decoding_errors_label.setObjectName("decoding_errors_label")
-        self.gridLayout_2.addWidget(self.decoding_errors_label, 4, 1, 1, 1)
-        self.label_2 = QtWidgets.QLabel(Decoder)
-        self.label_2.setObjectName("label_2")
-        self.gridLayout_2.addWidget(self.label_2, 0, 0, 1, 1)
+        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
+        self.gridLayout_2.addItem(spacerItem2, 0, 1, 1, 1)
         self.inpt = QtWidgets.QLineEdit(Decoder)
         self.inpt.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
         self.inpt.setObjectName("inpt")
         self.gridLayout_2.addWidget(self.inpt, 1, 1, 1, 1)
-        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
-        self.gridLayout_2.addItem(spacerItem4, 0, 1, 1, 1)
+        self.combobox_signals = QtWidgets.QComboBox(Decoder)
+        self.combobox_signals.setObjectName("combobox_signals")
+        self.combobox_signals.addItem("")
+        self.gridLayout_2.addWidget(self.combobox_signals, 1, 0, 1, 1)
         self.graphicsView_signal = ZoomableGraphicView(Decoder)
         self.graphicsView_signal.setObjectName("graphicsView_signal")
-        self.gridLayout_2.addWidget(self.graphicsView_signal, 2, 0, 1, 2)
+        self.gridLayout_2.addWidget(self.graphicsView_signal, 4, 0, 1, 2)
+        self.label_2 = QtWidgets.QLabel(Decoder)
+        self.label_2.setObjectName("label_2")
+        self.gridLayout_2.addWidget(self.label_2, 0, 0, 1, 1)
         self.graphicsView_decoded = ZoomableGraphicView(Decoder)
         self.graphicsView_decoded.setObjectName("graphicsView_decoded")
-        self.gridLayout_2.addWidget(self.graphicsView_decoded, 3, 0, 1, 2)
+        self.gridLayout_2.addWidget(self.graphicsView_decoded, 5, 0, 1, 2)
+        self.output = QtWidgets.QLineEdit(Decoder)
+        self.output.setReadOnly(True)
+        self.output.setObjectName("output")
+        self.gridLayout_2.addWidget(self.output, 3, 1, 1, 1)
+        self.label_3 = QtWidgets.QLabel(Decoder)
+        self.label_3.setObjectName("label_3")
+        self.gridLayout_2.addWidget(self.label_3, 3, 0, 1, 1)
         self.verticalLayout_4.addLayout(self.gridLayout_2)
+        self.decoding_errors_label = QtWidgets.QLabel(Decoder)
+        self.decoding_errors_label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
+        self.decoding_errors_label.setObjectName("decoding_errors_label")
+        self.verticalLayout_4.addWidget(self.decoding_errors_label)
 
         self.retranslateUi(Decoder)
         self.optionWidget.setCurrentIndex(5)
@@ -323,7 +324,7 @@ class Ui_Decoder(object):
         self.saveas.setText(_translate("Decoder", "Save as..."))
         self.label_8.setText(_translate("Decoder", "Base Functions"))
         self.label_9.setText(_translate("Decoder", "Additional Functions"))
-        self.label.setText(_translate("Decoder", "Decoder"))
+        self.label.setText(_translate("Decoder", "Your Decoding"))
         self.gb_infoandoptions.setTitle(_translate("Decoder", "Information and Options"))
         self.info.setText(_translate("Decoder", "Please drag functions from the categories base and additional to the decoding process (Decoder). You can reorder functions by drag and drop and remove functions by dropping them outside the Decoder box. Click on every function for detailed information."))
         self.label_5.setText(_translate("Decoder", "Number of redundant bits"))
@@ -346,10 +347,12 @@ class Ui_Decoder(object):
         self.label_17.setText(_translate("Decoder", "Maximum (<=) length of 1-sequence for: Low (0)"))
         self.label_18.setText(_translate("Decoder", "Minimum (>=) length of 1-sequence for: High (1)"))
         self.label_19.setText(_translate("Decoder", "Number of 0s between 1-sequences (just for encoding)"))
-        self.label_3.setText(_translate("Decoder", "Decoded Bits:"))
+        self.btnAddtoYourDecoding.setText(_translate("Decoder", "Add to Your Decoding"))
         self.combobox_signals.setItemText(0, _translate("Decoder", "Test"))
-        self.decoding_errors_label.setText(_translate("Decoder", "[Decoding Errors = 0]"))
         self.label_2.setText(_translate("Decoder", "Signal {0,1}:"))
+        self.label_3.setText(_translate("Decoder", "Decoded Bits:"))
+        self.decoding_errors_label.setText(_translate("Decoder", "[Decoding Errors = 0]"))
+
 
 from urh.ui.ListWidget import ListWidget
 from urh.ui.views.ZoomableGraphicView import ZoomableGraphicView
